@@ -262,7 +262,7 @@ mime_edit_dialog_class_init (MimeEditDialogClass *class)
 		 g_param_spec_pointer ("mime-type-info",
 				       _("MIME type information"),
 				       _("Structure with data on the MIME type"),
-				       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				       G_PARAM_READWRITE));
 
 	g_object_class_install_property
 		(object_class, PROP_IS_ADD,
@@ -270,7 +270,7 @@ mime_edit_dialog_class_init (MimeEditDialogClass *class)
 				       _("Is add dialog"),
 				       _("True if this dialog is for adding a MIME type"),
 				       FALSE,
-				       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				       G_PARAM_READWRITE));
 
 	dialog_signals[DONE] =
 		g_signal_new ("done",
@@ -406,11 +406,9 @@ mime_add_dialog_new (GtkTreeModel *model, GtkWindow *parent,
 		     char const *file_name) 
 {
 	GObject *dialog = g_object_new (mime_edit_dialog_get_type (),
-		"model", model,	/* must be before is-add */
+		"model", model,	"is-add", TRUE, /* model must be before is-add */
 		NULL);
-	g_object_set (dialog,
-		      "is-add", TRUE,
-		      NULL);
+
 	if (parent != NULL)
 		gtk_window_set_transient_for (
 			GTK_WINDOW (MIME_EDIT_DIALOG (dialog)->p->dialog_win),
@@ -455,6 +453,8 @@ safe_set_entry (MimeEditDialog *dialog, char const *widget, char const *txt)
 static void
 fill_dialog (MimeEditDialog *dialog)
 {
+	gchar *category_name;
+	
 	g_return_if_fail (dialog->p->info != NULL);
 
 	mime_type_info_load_all (dialog->p->info);
@@ -463,9 +463,10 @@ fill_dialog (MimeEditDialog *dialog)
 		dialog->p->info->description);
 	safe_set_entry (dialog, "mime_type_entry",
 		dialog->p->info->mime_type);
-	safe_set_entry (dialog, "category_entry",
-		mime_type_info_get_category_name (dialog->p->info));
-
+	category_name = mime_type_info_get_category_name (dialog->p->info);
+	safe_set_entry (dialog, "category_entry", category_name);
+	g_free (category_name);
+	
 	update_sensitivity (dialog);
 
 	gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (WID ("icon_entry")), mime_type_info_get_icon_path (dialog->p->info));
@@ -511,6 +512,10 @@ populate_component_list (MimeEditDialog *dialog)
 	menu = GTK_MENU (gtk_menu_new ());
 
 	component_list = gnome_vfs_mime_get_all_components (dialog->p->info->mime_type);
+	dialog->p->component_active = (component_list != NULL);
+	component_select = GTK_OPTION_MENU (WID ("component_select"));
+	gtk_option_menu_set_menu (component_select, GTK_WIDGET (menu));
+	update_sensitivity (dialog); /* do not add items to an insensitive menu */
 
 	/* FIXME: We are leaking the whole list here, but this will be the case until I know of an easy way to duplicate
 	 * Bonobo_ServerInfo structures */
@@ -537,8 +542,6 @@ populate_component_list (MimeEditDialog *dialog)
 		gtk_widget_show (menu_item);
 	}
 
-	dialog->p->component_active = !(i == 0);
-
 	menu_item = gtk_menu_item_new_with_label (_("None"));
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 	gtk_widget_show (menu_item);
@@ -546,11 +549,7 @@ populate_component_list (MimeEditDialog *dialog)
 	if (found_idx < 0)
 		found_idx = i;
 
-	component_select = GTK_OPTION_MENU (WID ("component_select"));
-	gtk_option_menu_set_menu (component_select, GTK_WIDGET (menu));
 	gtk_option_menu_set_history (component_select, found_idx);
-
-	update_sensitivity (dialog);
 }
 
 static void
@@ -566,6 +565,10 @@ populate_application_list (MimeEditDialog *dialog)
 	menu = GTK_MENU (gtk_menu_new ());
 
 	app_list  = gnome_vfs_mime_get_short_list_applications (dialog->p->info->mime_type);
+	dialog->p->default_action_active = (app_list != NULL);
+	app_select = GTK_OPTION_MENU (WID ("default_action_select"));
+	gtk_option_menu_set_menu (app_select, GTK_WIDGET (menu));
+	update_sensitivity (dialog); /* do not add items to an insensitive menu */
 
 	for (tmp = app_list, i = 0; tmp != NULL; tmp = tmp->next, i++) {
 		app = tmp->data;
@@ -586,7 +589,6 @@ populate_application_list (MimeEditDialog *dialog)
 		gtk_widget_show (menu_item);
 	}
 
-	dialog->p->default_action_active = !(i == 0);
 	dialog->p->custom_action = (found_idx < 0);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), gtk_menu_item_new_with_label (_("Custom")));
@@ -604,13 +606,9 @@ populate_application_list (MimeEditDialog *dialog)
 		gtk_widget_set_sensitive (WID ("program_entry_box"), FALSE);
 	}
 
-	app_select = GTK_OPTION_MENU (WID ("default_action_select"));
-	gtk_option_menu_set_menu (app_select, GTK_WIDGET (menu));
 	gtk_option_menu_set_history (app_select, found_idx);
 
 	g_list_free (app_list);
-
-	update_sensitivity (dialog);
 }
 
 static void
@@ -716,7 +714,7 @@ mime_edit_dialog_get_app (GladeXML *glade, char const *mime_type,
 
 			res->name = base_cmd;
 			if (res->name != NULL && *res->name) {
-				/* Can we use the app name as the id ?
+				/* Can we use the app name as the id?
 				 * We know that there are no apps with the same
 				 * command, so if the id is taken we are screwed
 				 */
@@ -856,8 +854,15 @@ validate_data (MimeEditDialog *dialog)
 				GTK_WINDOW (dialog->p->dialog_win),
 				GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_OK_CANCEL,
-				_("A MIME type with that name already exists, overwrite ?."));
+				_("A MIME type with that name already exists, overwrite?"));
 		}
+	} else {
+		err_dialog = gtk_message_dialog_new (
+			GTK_WINDOW (dialog->p->dialog_win),
+			GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_CANCEL,
+			_("Please enter a valid MIME type.  It should be of the form "
+			  "class/type and may not contain any spaces."));
 	}
 
 	if (err_dialog) {
